from datetime import datetime

def print_with_level(level, message):
    """打印带有时间戳和级别的消息"""
    timestamp = datetime.now().strftime('%Y-%m-%d %H:%M:%S')
    print(f"{timestamp} - {level} - {message}")

def debug(message):
    print_with_level("DEBUG", message)

def info(message):
    print_with_level("INFO", message)

def warning(message):
    print_with_level("WARNING", message)

def error(message):
    print_with_level("ERROR", message)

def critical(message):
    print_with_level("CRITICAL", message)

def exception(message):
    """打印异常信息"""
    import traceback
    print_with_level("ERROR", f"{message}\n{traceback.format_exc()}")

# 兼容性函数
def get_logger(name=None, level=None, log_dir=None, log_to_file=True):
    """返回一个模拟logger的对象，实际上只是打印到控制台"""
    return type('Logger', (), {
        'debug': debug,
        'info': info,
        'warning': warning,
        'error': error,
        'critical': critical,
        'exception': exception
    })()

def set_global_level(level):
    """为了保持兼容性，这个函数实际上不做任何事"""
    pass